DatadogLogger class

Constructors

DatadogLogger({String? loggerName, bool bindOnRecord = true})

Properties

hashCode → int
The hash code for this object.
no setterinherited
loggerName → String?
The value for the logger.name attribute attached to all logs sent to Datadog. This can be overriden by providing the loggerName attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAttribute(String attributeName, String value) → Future<void>
Adds an attribute to all future messages from this logger.
addTag(String tagName, String value) → Future<void>
Adds a tag to all future messages from this logger.
levelAsStatus(Level level) → String
log(String logMessage, Level logLevel, {Map<String, dynamic>? attributes}) → Future<void>
Log message directly.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRecordCallback(LogRecord record) → Future<void>
Useful shorthand to attch to the logger stream: Logger.root.onRecord.listen(myDatadogLogger.onRecordCallback);
removeAttribute(String attributeName) → Future<void>
Removes a previously-added attribute from all future messages from this logger.
removeTag(String tagName) → Future<void>
Removes a previously-added tag from all future messages from this logger.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited