DatadogTracing class

Constructors

DatadogTracing()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createHeaders({String? method, required String resourceName, String? url}) → Future<Map<String, String>>
Generates headers to inject in DatadogTracingHttpClient.
finishSpan(String spanId, {int? statusCode}) → Future<void>
Acknowledges the completion of a task.
initialize() → Future<void>
The tracer must be initialized before making any requests with DatadogTracingHttpClient.