Metric class

A reportable metric to be synced with Datadog

Constructors

Metric(String _name, MetricType type, List<List<int>> value, {String? host, int? interval, String? prefix, Set<String>? tags})
const

Properties

asJson → String
no setter
asMap → Map<String, dynamic>
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
interval → int?
final
name → String
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Set<String>?
final
type → MetricType
final
typeAsString → String
no setter
value → List<List<int>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited